/*                      ONE WAY LAYOUT                   */

/*The following macros will be used:
LD_CI (for relative effects and their confidence intervals)
OWL  (One Way Layout)*/

/*Set the pathways to the macros for your computer*/
%INCLUDE 'C:\Documents and Settings\madden.1\My Documents\temp\Workshop files\Macros\LD_CI.sas';
%INCLUDE 'C:\Documents and Settings\madden.1\My Documents\temp\Workshop files\Macros\OWL.sas';


/*Data courtesy of Ann Cobb, NYSAES*/
/*Effect of foliar fungicides on the control of Alternaria brassicicola*/
/*on cabbage.  Greenhouse test.*/
/*Disease ratings done on a 0-9 scale*/
/*0 = no flecks*/
/*1 = 3 flecks or less*/
/*2 = 8 to 10 flecks*/
/*3 = >10 flecks per leaf*/
/*4 = flecks with any large lesion (>1cm) or moderate number on center leaves*/
/*5 = >10 flecks and 1 large lesion*/
/*6 = 10 flecks and/or many large lesions in center of plant or head*/
/*7 = a few collapsed leaves*/
/*8 = most plants collapsed, some green leaves with flecks*/
/*9 = collapsed plant*/

/*Ratings done 7 days post inoculation*/
/*sub = subject*/
/*trt = fungicide treatment*/
/*rep = replicate: there are 4 reps*/
/*exp = experiment (1 2 3 4). Only exp 3 data shown here.*/
/*rating = rating on the 0-9 scale*/

options ls =100 ps= 1000 nodate nonumber;
data cobb;
input sub trt $ rep exp rating;
cards;
1	actigard	1	3	7
2	actigard	2	3	7
3	actigard	3	3	7
4	actigard	4	3	6
5	bravo	1	3	7
6	bravo	2	3	7
7	bravo	3	3	3
8	bravo	4	3	3
9	control	1	3	7
10	control	2	3	7
11	control	3	3	6
12	control	4	3	7
13	folicur	1	3	3
14	folicur	2	3	6
15	folicur	3	3	5
16	folicur	4	3	3
17	quadris	1	3	2
18	quadris	2	3	3
19	quadris	3	3	3
20	quadris	4	3	4
21	rovral	1	3	1
22	rovral	2	3	0
23	rovral	3	3	1
24	rovral	4	3	1
;
run;

/*Check the data*/
title 'ORIGINAL DATASET';
proc print data=cobb;
run;

/*Calculate the ranks*/
proc rank data=cobb out=cobb;
	var rating;
    ranks r;
run;
/*Make sure data is sorted by main effects*/
proc sort data=cobb out=cobb;
  by trt rep;
run;
title 'DATA WITH RANKS';
proc print data=cobb;
run;
/*Summary of the data. Easier to look at in table form*/
title 'MEDIAN RATINGS';
proc tabulate data=cobb f=6.2;
  class trt;
  var rating;
  table trt*rating*(median); *<--Request median rating per trt;
run;


/*One way analysis of the marginal effects using Mixed*/
/*Note it is not necessary to specify the method= option in the 1-way case*/
title 'ONE-WAY ANALYSIS USING PROC MIXED';
proc mixed data=cobb anovaf  method=mivque0; 
	class trt;
	model r = trt / chisq;
	repeated / type=un(1) group=trt;
	lsmeans trt;
	ods output lsmeans=c; *<--Output the lsmeans to dataset c, for plotting later;

	/*Contrast used to test treatment differences of interest*/
	contrast 'actigard vs control' trt 1 0 -1 0 0 0;
	contrast 'bravo vs control' trt 0 1 -1 0 0 0;
	contrast 'folicur vs control' trt 0 0 1 -1 0 0;
	run;

/*                 PLOTTING RELATIVE TREATMENT EFFECTS                */
/*One may want to visualize the relative treatment effects.
  Here we calculate the relative treatment effects from the lsmeans*/
data c2;
  set c;
  re = (Estimate-0.5)/24; *<-- re are the relative treatment effects;
  drop Effect DF tValue Probt; *<-- Just cleaning up a bit;
run;
title 'RELATIVE TREATMENTS EFFECTS CALCULATED FROM PROC MIXED LSMEANS';
proc print data=c2;
run;

proc tabulate data=c2;
class trt;
  var re;
  table trt*re*(mean); *<--Tables the relative effects;
run;

/*Now plot re*/
goptions reset=all;
symbol1 v=dot c=red i=needle;
title 'PLOT OF RELATIVE TREATMENT EFFECTS';
proc gplot data = c2;
  plot re*trt;
run;
quit;

/*                 CONFIDENCE INTERVALS          */
/* Confidence intervals and variances for the relative treatment (marginal) effects*/
title 'CONFIDENCE INTERVALS USING THE LD_CI MACRO';
%LD_CI(data=cobb,var=rating,group=trt,alpha=0.05,subject=sub);

/*                   One Way Layout MACRO         */
/*Perform the same analysis using the OWL macro*/
title 'ANALYSIS USING THE OWL MACRO';
%owl(data=cobb,var=rating,group=trt);



%macro skip;
/*           KRUSKAL-WALLIS TEST FOR ONE-WAY LAYOUT               */

/*You can use either Proc npar1way or Proc Mixed to do the Kruskal-Wallis test*/
/*For example, Kruskal-Wallis test using Proc npar1way*/
title 'DIRECT 1-WAY KRUSKAL-WALLIS ANALYSIS WITH SAS PROC NPAR1WAY';
proc npar1way data=cobb wilcoxon;
	class trt;
	var rating;
run;

/*Kruskal-Wallis test using Proc Mixed, assuming no ties*/
title 'KRUSKAL-WALLIS USING PROC MIXED, ASSUME NO TIES';
proc mixed data=cobb;
class trt;
model r = trt / chisq;  *<--the WTS is the K-W statistic here;
parms (50) / eqcons=1; *<--Specifies and holds constant the theoretical K-W variance, N(N+1)/12;
run;

/*If there are ties in the data, then the theoretical K-W variance is not N(N+1)/12*/
/*You can calculate the K-W variance (when there are ties) as below:
Get the square of the ranks*/
data sqr;
  set cobb;
  rsq = r*r;
run;
proc means data=sqr sum;  *<--Get the sum of the squared ranks;
  var rsq;
  output out=a2 sum(rsq)=sumr; *<--Write the sum of the squared ranks to a2 under variable sumr;
run;
/*Now use sumr to calculate the K-W variance*/
data a3;
 set a2;
 n=24; *<--Set to the number of observations;
 est = (1/(n-1))*(sumr - ((n*(n+1)*(n+1))/4)); *<--Calculate the K-W variance;
 drop n sumr _type_ _freq_;
 run;
 title 'K-W VARIANCE WHEN THERE ARE TIES';
 proc print data=a3;
 run;

/*Kruskal Wallis using Proc Mixed, with ties*/
title 'KW USING PROC MIXED, ADJUSTED FOR TIES';
proc mixed data=cobb;
class trt;
model r = trt / chisq;
parms / parmsdata=a3 eqcons=1; *<--The K-W variance is read from the variable est in dataset a3;
run;
%mend skip;





