         /*REPEATED MEASURES: ONE GROUP SEVERAL TIME POINTS*/

/*Requires the following macros:
F1_LD_F1
LD_CI*/

/*Specify the pathways to the macros for your computer*/
%INCLUDE 'C:\Documents and Settings\Denis Shah\My Documents\Nonparametrics\Macros\LD_CI.sas';
%INCLUDE 'C:\Documents and Settings\Denis Shah\My Documents\Nonparametrics\Macros\F1_LD_F1.sas';

/*
Five crabapple varieties were evaluated four times during the season for apple scab.

variety = crabapple variety: A D MP RJ ST
year = year: we are not using this variable
rep = replication 1 to 5
t1 - t4: apple scab rating at times 1-4

scab ratings were made on a 0-5 scale, with 0 = no scab observed; 
1 = less than 5% of leaves affected and no aesthetic impact; 
2 = 5-20% of leaves affected, with some yellowing but little or no defoliation, 
moderate aesthetic impact; 
3 = 20-50% of leaves affected, significant defoliation and/or leaf yellowing, 
substantial aesthetic impact; 
4 = 50-80% of leaves affected, severe foliar discoloration and defoliation, 
severe aesthetic impact; 
and 5 = 80-100% of foliage affected, with 90-100% defoliation.
*/
options ls =100 ps= 1000 nodate nonumber;
data a;
input variety $ year rep t1 t2 t3 t4;
sub1=right(variety)||"_"||left(put(rep,1.)); *<--subject: each combination of variety and rep;
datalines;
A	2000	1	1	1	2	3
A	2000	2	2	2	3	3
A	2000	3	2	2	3	3
A	2000	4	2	2	3	3
A	2000	5	1	2	2	3
D	2000	1	0	1	1	2
D	2000	2	0	1	1	2
D	2000	3	0	1	1	2
D	2000	4	0	1	1	2
D	2000	5	0	1	1	2
MP	2000	1	1	1	1	1
MP	2000	2	1	2	2	2
MP	2000	3	1	1	1	2
MP	2000	4	1	1	1	2
MP	2000	5	1	1	1	1
RJ	2000	1	1	2	3	4
RJ	2000	2	2	2	3	4
RJ	2000	3	1	2	3	4
RJ	2000	4	1	2	3	4
RJ	2000	5	1	2	3	3
ST	2000	1	1	1	1	2
ST	2000	2	1	1	1	1
ST	2000	3	1	2	2	2
ST	2000	4	1	1	1	2
ST	2000	5	1	1	1	2
;
run;
/*The data must be converted to univariate format for the macros and Proc Mixed.*/
data b;
	set a;
	array t{4} t1-t4;
	do i=1 to 4;
		if i=1 then time=1;
		if i=2 then time=2;
		if i=3 then time=3;
		if i=4 then time=4;
		rating=t{i};
		output;
	end;
	drop i t1-t4 year; *<--Don't need these;
 run;
 /*Check the data*/
 title 'CRABAPPLE DATASET';
 proc print data = b;
 run;

 /*Summary of the median ratings*/
title 'MEDIAN RATINGS SUMMARY';
proc tabulate data=b f=6.1;
  class variety time;
  var rating;
  table variety, time*rating*(median); *<--Request median rating;
run;


/*Nonparametric analysis using the F1_LD_F1 macro*/
title 'ANALYSIS WITH THE F1_LD_F1 MACRO';
%f1_ld_f1(data=b,var=rating,factor=variety,time=time,subject=sub1);

/*Get the relative treatment effects and their 95% confidence limits*/
title 'RELATIVE EFFECTS';
%LD_CI(data=b, var=rating, group=variety, time=time, subject=sub1, alpha=0.05);
run;

/*If you want to examine specific patterned alternatives*/
/*First create the dataset with the hypothesized alternative pairwise interactions*/
data interaction_pattern; *<-- This example hypothesizes an increasing separation over time;
input time weight;
cards;
1 1
2 2
3 3
4 4
;
run;
/*For patterned alternative, you need a few more parameters in the F1_LD_F1 macro*/
title 'PATTERNED ALTERNATIVES WITH THE F1_LD_F1 macro';
%f1_ld_f1(data=b,var=rating,factor=variety,time=time,subject=sub1, 
            data_pit=interaction_pattern, var_pit=weight, time_pit=time);


			/*        ANALYSIS USING PROC MIXED    */
title 'NONPARAMETRIC ANALYSIS USING PROC MIXED';
/*Obtain the ranks*/
proc rank data=b out=b;
var rating; 
ranks r1;
run;

/*Make sure data is sorted by subject and time*/
proc sort data=b out=b;
  by sub1 time;
run;

proc mixed data=b anovaf method=mivque0;
	class variety sub1 time;
	model r1 = variety|time / chisq;
	repeated / sub=sub1 group=variety type=un r rcorr; *<--r , rcorr display parts of the R and correlation matrix;
	lsmeans variety*time;
	ods output lsmeans=c; *<--Output the lsmeans to dataset c;
	contrast 'RJ vs ST at t=1' variety 0 0 0 1 -1
         variety*time 0 0 0 0  0 0 0 0  0 0 0 0  1 0 0 0  -1 0 0 0;
	contrast 'RJ vs ST at t=4' variety 0 0 0 1 -1
         variety*time 0 0 0 0  0 0 0 0  0 0 0 0  0 0 0 1  0 0 0 -1;
	contrast 'A RJ vs D MP ST t=4' variety 3 -2 -2 3 -2
         variety*time 0 0 0 3  0 0 0 -2  0 0 0 -2  0 0 0 3  0 0 0 -2;
	contrast 'D vs ST at t=4' variety 0 1 0 0 -1 
         variety*time 0 0 0 0  0 0 0 1  0 0 0 0  0 0 0 0  0 0 0 -1;
    contrast 'A vs RJ at t=4' variety 1 0 0 -1 0 
         variety*time 0 0 0 1  0 0 0 0  0 0 0 0  0 0 0 -1  0 0 0 0;
run;


/*Calculate the relative treatment effects from the lsmeans*/
data c2;
  set c;
  re = (Estimate-0.5)/100; *<-- re are the relative treatment effects;
  drop Effect DF tValue Probt; *<-- Just cleaning up a bit;
run;
title 'RELATIVE TREATMENT EFFECTS CALCULATED FROM PROC MIXED LSMEANS';
proc tabulate data=c2 f=6.1;
  class variety time;
  var re;
  table variety, time*re*(mean); *<--Table of the relative effects;
run;

/*Now plot re*/
title 'RELATIVE EFFECTS FOR VARIETY';
symbol1 v=dot i=join;
proc gplot data = c2;
  plot re*time = variety;
run;
quit;




