%macro NDF(data=,group=,x=,minx=0,char=no, print=no);

/*******************************************************************************
Macro plots the normalized empirical (estimated) distribution for several 
groups and also plots the empirical normalized mean weighted distribution (H).
Plots the F^(x) and H^(x) values versus x.
Note: H is labeled as !-! (in order to be sorted first), and is a thin solid 
black line. Actual groups have thicker broken lines (different colors).
Up to 16 groups.

There are other ways in SAS to get cumulative distributions, but this macro
also determines H^(x), also extends the lines to values lower than the
smallest x (giving a 'nice look' at the low values of the response), and 
also prints out left-, right-, and normalized empirical F (on request).

data:		data file
group:		name of grouping variable
x:			name of response variable
minx:		lower limit for x; MUST make smaller than actual min(X).
char:		Is the grouping variable character or numeric? (yes/no)
			(Must specify if groups are labeled with character names)
print:		Say Yes to print file with raw data (group &x), as well as the 
			left-, right-, and normalized empirical F.

*******************************************************************************/

%let ds='Data set: '; %let rv=' Response variable:'; 
%let ft = &ds &data &rv &x;
%let ft2 = 'Empirical (estimated) normalized distribution functions (and H^ = !-!)';
footnote &ft2;
footnote2 &ft;

%if (%UPCASE(&char) eq NO) %then %do;
	data __aT; set &data;
		grp=put(&group,Z6.);
	data _aaT; set &data;
		grp = '!-!';
	%end;
%if (%UPCASE(&char) eq YES) %then %do;
	data __aT; set &data;
		grp=&group;
	data _aaT; set &data;
		grp = '!-!';
	%end;

data _a; set __aT _aaT;
*proc print data=_a;
*proc print data=_a;

proc sort data=_a out=_a;
	by grp &x;
proc rank data=_a out=_a F; *--get RIGHT-continuous, for graphics only;
	by grp;
	var &x; ranks rx;
proc rank data=_a out=_a ; *--get normalized F, for possible printing or later use;
	by grp;
	var &x; ranks normF;

/*
Note: the above rank procedure with F option is really calculating the _RIGHT_
continuous F(x), _not_ normalized F. But, when this is coupled with the 
LEFT-sided join-step with GPLOT (see LABELs, below), the graph has the right look.
That is, for each vertical "jump" or join:
	the bottom of the vertical line is the left-continuous F [F-(x)], 
	the top of the line is the right-continuous [F+(x)],
	and the center of the vertical line is the normalized F [F(x)].
*/

proc summary data=_a nway;
    class grp;
    var &x;
    output out=_b(drop = &x _type_)  n=;
*proc print data=_b;

data _btemp ; set _b;
	rx = 0;
	&x=&minx;
*proc print data=_btemp;

data _c;
    merge _a _b;
    by grp;
	frq=_FREQ_;
	label rx ='F^(x)';
	label grp ='Group';
	normF=(normF-0.5)/frq;	*--This is the true estimated Normalized F^(x);
	leftF=2*normF - rx; 	*--left continuous F^(x);
	rightF=rx;				*--right continuous F^(x);


data _c; set _c _btemp;
%if (%UPCASE(&print) = YES) %then %do;
	proc print data=_c;
		var grp &x leftF normF rightF;
	%end;

*title2 'Empirical (Estimated) NORMALIZED DISTRIBUTIONS';
proc sort data=_c out=_c;
	by &x;

symbol1 c=black  i=steplj l=1 w=1 v=none;  *--first group is for H^;
symbol2 c=blue  i=steplj l=4 w=2 v=none;
symbol3 c=red  i=steplj l=5 w=2 v=none;
symbol4 c=green i=steplj l=6 w=2 v=none;
symbol5 c=rbk  i=steplj l=20 w=2 v=none;
symbol6 c=salmon i=steplj l=8 w=2 v=none;
symbol7 c=brown i=steplj l=9 w=2 v=none;
symbol8 c=purple i=steplj l=10 w=2 v=none;
symbol9 c=gray i=steplj l=3 w=2 v=none;
symbol10 c=vigb i=steplj l=12 w=2 v=none;
symbol11 c=dapb i=steplj l=13 w=2 v=none;
symbol12 c=vib i=steplj l=14 w=2 v=none;
symbol13 c=stolg i=steplj l=15 w=2 v=none;
symbol14 c=bio i=steplj l=16 w=2 v=none;
symbol15 c=vip i=steplj l=17 w=2 v=none;
symbol16 c=str i=steplj l=18 w=2 v=none;
symbol17 c=vdabg i=steplj l=19 w=2 v=none;
axis1 w=2 label=(angle=90 rotate=0) minor=none;
axis2 w=2 label=(angle=0 rotate=0) minor=none;
*proc print data=_c;
proc gplot data=_c;
	plot  rx*&x=grp / frame cframe=gwh vaxis=axis1 haxis=axis2 ;
/*If one used a minx bigger than actual min(X), strange graphs are produced.*/
run;

/* Clean up the data sets, etc. */
proc datasets nodetails; 
	delete __aT _aaT _a _b _bTemp;
title2 ;
footnote ;
footnote2 ;
goptions reset=all;
run;
%mend;
