/*
Program shows the linkages between several statistics that can be
calculated for the two-group problem (with independent data).
Basically, this shows how to obtain area under the ROC, probability
of superiority (PS), relative treatment effect of Brunner et al., 
and related statistics using differerent procedures.
Among other things, this shows that 
	p = p_2 - p_1 + 1/2 
from Brunner is identical to PS (area, etc.). Plus, this shows that PS (and p)
can also be obtained from Somer's D. 

Generate 10 independent observations for both treatments 1 and 2.
Treatment 1 has a *theoretical* expected value of 3 (= 3*1), 
and treatment 2 has a theoretical expected value of 6 (= 3*2)).

Program requires the OWL macro to be in designated folder.
*/

title 'Demonstration of linkages between PS, Somers D, c, rel. treat. effects, ...';
/*
*---simulated data (not used now);
data a;
call streaminit(1);		*---lock in seed for random number gener.;
do i = 1 to 10;
	do treat = 1 to 2;
		x = rand('Poisson', 3*(treat))  ;
		output;
	end;
end;
run;
*/

data a;					*---example data, generated as Poisson;
input treat x;
datalines;
1 5
2 11
1 3
2 9
1 4
2 10
1 6
2 6
1 4
2 9
1 3
2 7
1 5
2 10
1 4
2 3
1 5
2 6
1 2
2 10
;
proc print data=a;		*---look at the generated data;
title2 'Generated data';
run;
proc means data=a mean median var ;		*---check out the parametric summary statistics;
title2 'Parametric summary';
class treat;
var x;
run;

proc npar1way data=a wilcoxon;
	title2 'Look at the Wilcoxon scores';
	title3 'U: larger of the two Sum of Scores minus (10*(10+1)/2)';
	title4 '(assuming that sample sizes are 10 and 10)';
	title5 'PS is U /(10*10)';
	footnote1 'U = 146-55 = 91, PS=91/(10*10) = 0.91';
	class treat;
	var x;
run;
title2; title3; title4; title5; footnote1;
proc rank data=a out=a;		*---rank the data;
	var x; ranks rx;
run;
proc sort data=a out=asort;	*---sort for ease of viewing;
	by treat x;
run;
proc print data=asort;
	title2 'Generated data, with ranks';
run;						*---look at sorted and ranked data;

proc means data=a mean sum;
	title2 'rel. trt. effect 1 (p_1) = (mean rank_1 - 1/2)/(10+10)';
	title3 'rel. trt. effect 2 (p_2) = (mean rank_2 - 1/2)/(10+10)';
	title4 'p = p_2 - p_1 + 1/2 (same as PS and area under ROC';
	title5 '(assuming that sample sizes are 10 and 10)';
	footnote1 'p_1 = (6.4-0.5)/(10+10) = 0.295';
	footnote2 'p_2 = (14.6-0.5)/(10+10) = 0.705';
	class treat;
	var rx;
run;

/*
With the above generated Poisson data (10 observations for each group), 
and the designated random-number seed, one gets:
	p^_1 = 0.295
	p^_2 = 0.705
	p = 0.705 - 0.295 + 1/2 = 0.91 = PS = c = area under ROC
*/

*---Use PROC FREQ to get Somer's D, and hence p (and PS) ;

proc freq data=a ;
	title2 'Somers D (C|R) is the same as 2*p - 1 ';
	title3 'Somers D (C|R) is also same as 2*(area under ROC) - 1';
	title4; title5;
	footnote1 'p = PS = area = (0.82+1)/2 = 0.91';
	table treat*x / all measures noprint ;
run;
title2; title3; title4; title5; footnote1;
run;

*---Now use the Brunner OWL macro for a one-way-layout (put in right Path).;

%INCLUDE 'C:\Documents and Settings\madden.1\My Documents\My SAS Files\OWL.sas';
title2 'Analysis using the OWL macro (from Edgar Brunner)';
title3 'p_i is the rel. treat. effect (p_1 and p_2)';
title4 'p = p_2 - p_1 + 1/2 (when there are just two groups with indep. observ.';
title5 'p is the same as PS and area under ROC (with two groups, indep. data)';
footnote1 'p = p_2 - p_1 + 1/2 = 0.705 - 0.295 + 1/2 = 0.91';
%owl(data=a,var=x,group=treat);
run;
title2;title3;title4;title5;footnote1;
run;

*---Another way to get area under ROC (or p or PS);
*---One uses the treatment code as the response, and response as the predictor;
proc logistic data=a descending;
title2 'Use LOGISTIC to get area under ROC (or p or PS)';
title3 'c is same as area under ROC (or p or PS)';
title4 'Somers D is same as 2*p - 1';
title5;
footnote1 'c = PS = area = 0.91 = (0.820 + 1)/2';
model treat = x;
run;
title2;title3;title4;title5;footnote1;
run;

